@@ -1,10 +1,8 @@
 import typing
-from aws_cdk import (
-    aws_codebuild as cb
-)
+from aws_cdk import aws_codebuild
 
 
-def buildenv(environment_variables: dict) -> typing.Dict[str, cb.BuildEnvironmentVariable]:
+def buildenv(environment_variables: dict) -> typing.Dict[str, aws_codebuild.BuildEnvironmentVariable]:
     """Facilitate Codebuild environmemt creation
     Simply pass your dict to be turned a env variabltes
     For values that starts with 'aws:sm:', the prefix will be striped off
@@ -14,21 +12,21 @@ def buildenv(environment_variables: dict) -> typing.Dict[str, cb.BuildEnvironmen
         environment_variables (dict): key/value store to turn into Codebuild Env
 
     Returns:
-        typing.Dict[cb.BuildEnvironmentVariable]: [description]
+        typing.Dict[aws_codebuild.BuildEnvironmentVariable]: [description]
     """
     envs = dict()
     for env, value in environment_variables.items():
         if isinstance(value, str) and value.startswith('aws:sm:'):
-            envs[env] = cb.BuildEnvironmentVariable(
+            envs[env] = aws_codebuild.BuildEnvironmentVariable(
                 value=value.replace('aws:sm:', ''),
-                type=cb.BuildEnvironmentVariableType.SECRETS_MANAGER
+                type=aws_codebuild.BuildEnvironmentVariableType.SECRETS_MANAGER
             )
         else:
-            envs[env] = cb.BuildEnvironmentVariable(value=value)
+            envs[env] = aws_codebuild.BuildEnvironmentVariable(value=value)
     return envs
 
 
-def load_buildspec(specfile: str='buildspec.yml') -> cb.BuildSpec:
+def load_buildspec(specfile: str='buildspec.yml') -> aws_codebuild.BuildSpec:
     """Load a buildspec yaml file
 
     Args:
@@ -41,4 +39,4 @@ def load_buildspec(specfile: str='buildspec.yml') -> cb.BuildSpec:
     with open(specfile, encoding="utf8") as fp:
         bsfile = fp.read()
         bs = yaml.safe_load(bsfile)
-        return cb.BuildSpec.from_object(value=bs)
+        return aws_codebuild.BuildSpec.from_object(value=bs)
