@@ -1,16 +1,17 @@
+from constructs import Construct
 from aws_cdk import (
+    Duration,
     aws_lambda,
     aws_stepfunctions as sfn,
-    aws_stepfunctions_tasks as sfn_tasks,
-    core
+    aws_stepfunctions_tasks as sfn_tasks
 )
 
 
-class Stepfunctions(core.Construct):
+class Stepfunctions(Construct):
     statemachine: sfn.IStateMachine = None
     start: sfn.IChainable = None
 
-    def __init__(self, scope: core.Construct, id: str, *, start: sfn.IChainable=None) -> None:
+    def __init__(self, scope: Construct, id: str, *, start: sfn.IChainable=None) -> None:
         super().__init__(scope, id)
 
         if not start:
@@ -21,7 +22,7 @@ class Stepfunctions(core.Construct):
         self.statemachine = sfn.StateMachine(
             self, name,
             definition=self.start,
-            timeout=core.Duration.minutes(timeout)
+            timeout=Duration.minutes(timeout)
         )
         return self.statemachine
 
